@@ -17,9 +17,9 @@
 #define _K3B_PLUGIN_H_
 
 #include "k3b_export.h"
-#include <KCoreAddons/KPluginFactory>
-#include <KService/KPluginInfo>
-#include <QtCore/QObject>
+#include <KPluginFactory>
+#include <KPluginInfo>
+#include <QObject>
 
 #define K3B_PLUGIN_SYSTEM_VERSION 5
 
@@ -38,8 +38,8 @@ namespace K3b {
         friend class PluginManager;
 
     public:
-        Plugin( QObject* parent = 0 );
-        virtual ~Plugin();
+        explicit Plugin( QObject* parent = 0 );
+        ~Plugin() override;
 
         KPluginInfo pluginInfo() const { return m_pluginInfo; }
 
